@@ -48,6 +48,10 @@ static gboolean             verbose;
 static int                  movie_width;
 static int                  movie_height;
 static int                  movie_length;
+static int                  crop_x;
+static int                  crop_y;
+static int                  crop_width;
+static int                  crop_height;
 static int                  screen;
 static gchar               *mrl;
 static gchar               *sub_mrl;
@@ -57,6 +61,8 @@ static const char          *playbin_name = "player";
 static const char          *dvd_device;
 static const char          *vcd_device;
 static GstElement          *gst_elm_play;
+static GstElement          *videosink;
+static GstElement          *videocrop;
 static GstBus              *gst_bus;
 static unsigned int /*GstMessageType*/       ignore_messages_mask;
 static GstXOverlay         *xoverlay;
@@ -508,7 +514,6 @@ gboolean Backend::isPlaying () {
 
 static void play () {
     GstElement *element;
-    GstElement *videosink = 0L;
     GstElement *audiosink = 0L;
     gboolean success;
     fprintf (stderr, "play %s\n", !mrl || !mrl[0] ? "<empty>" : mrl);
@@ -552,6 +557,14 @@ static void play () {
         videosink = gst_element_factory_make ("ximagesink", "videosink");
     if (!videosink)
         goto fail;
+
+    GstElement *bin = gst_bin_new ("cropvideosink");
+    videocrop = gst_element_factory_make ("videocrop", "videocrop");
+    gst_bin_add_many (GST_BIN (bin), videocrop, videosink, NULL);
+    gst_element_add_pad (bin, gst_ghost_pad_new ("sink",
+                gst_element_get_pad (videocrop, "sink")));
+    gst_element_link_many (videocrop, videosink, NULL);
+
     if (GST_IS_BIN (videosink))
         element = gst_bin_get_by_interface (GST_BIN (videosink),
                 GST_TYPE_X_OVERLAY);
@@ -564,6 +577,7 @@ static void play () {
     /*g_signal_connect (content, "expose-event", G_CALLBACK (cb_expose), videosink );*/
     gst_element_set_bus (videosink, gst_bus);
     gst_element_set_state (videosink, GST_STATE_READY);
+    gst_element_set_state (bin, GST_STATE_READY);
     success = gstPollForStateChange (videosink, GST_STATE_READY, GST_SECOND/2);
     /*if (!success) {
         / * Drop this video sink * /
@@ -575,7 +589,7 @@ static void play () {
         success = gstPollForStateChange (audiosink, GST_STATE_READY, GST_SECOND/2);
     }
     g_object_set (G_OBJECT (gst_elm_play),
-            "video-sink",  videosink,
+            "video-sink",  bin, /*videosink,*/
             "audio-sink",  audiosink,
             NULL);
     gst_bus_set_sync_handler (gst_bus, gst_bus_sync_signal_handler, 0L);
@@ -612,6 +626,7 @@ fail:
     if (videosink) {
         gst_element_set_state (videosink, GST_STATE_NULL);
         gst_object_unref (videosink);
+        videosink = NULL;
     }
     if (audiosink) {
         gst_element_set_state (audiosink, GST_STATE_NULL);
@@ -769,14 +784,14 @@ watchX11Events (GSource *source, GSourceFunc callback, gpointer data) {
         }
         case Expose:
             if (!xevent.xexpose.count && xevent.xexpose.window == wid) {
-                if (gst_elm_play) {
-                    GstElement *videosink;
+                if (gst_elm_play && videosink) {
+                    /*GstElement *videosink;
                     g_object_get (gst_elm_play, "video-sink", &videosink, NULL);
-                    if (videosink && GST_IS_X_OVERLAY (videosink)) {
+                    if (videosink && GST_IS_X_OVERLAY (videosink)) {*/
                         gst_x_overlay_set_xwindow_id (GST_X_OVERLAY (videosink), wid);
                         gst_x_overlay_expose (GST_X_OVERLAY (videosink));
-                        gst_object_unref (videosink);
-                    }
+                        /*gst_object_unref (videosink);
+                    }*/
                 }
             }
             break;
@@ -869,10 +884,22 @@ static gboolean cb_finished (gpointer data) {
 
 static gboolean cb_video_dimension (gpointer data) {
     Dimension *dim = (Dimension *) data;
-    output ("ID_VIDEO_WIDTH=%d\n", dim->width);
-    output ("ID_VIDEO_HEIGHT=%d\n", dim->height);
-    if (window_created && dim->width > 0 && dim->height > 0) {
-        XResizeWindow (display, wid, dim->width, dim->height);
+    int video_width = dim ? dim->width : movie_width;
+    int video_height = dim ? dim->height : movie_height;
+    if (gst_elm_play &&
+            (crop_x > 0 || crop_y > 0 || crop_width > 0 || crop_height > 0)) {
+        GObject *o = G_OBJECT (videocrop);
+        g_object_set (o, "top", crop_y, NULL);
+        g_object_set (o, "left", crop_x, NULL);
+        g_object_set (o, "right", video_width - crop_width - crop_x, NULL);
+        g_object_set (o, "bottom", video_height - crop_height - crop_y, NULL);
+        video_width = crop_width;
+        video_height = crop_height;
+    }
+    output ("ID_VIDEO_WIDTH=%d\n", video_width);
+    output ("ID_VIDEO_HEIGHT=%d\n", video_height);
+    if (window_created && video_width > 0 && video_height > 0) {
+        XResizeWindow (display, wid, video_width, video_height);
         XFlush (display);
     }
     g_free (dim);
@@ -907,16 +934,31 @@ static gboolean watchStdin (GIOChannel *src, GIOCondition cond, gpointer data) {
                         g_idle_add (cb_stop, NULL);
                     } else if (!strncmp (cmdbuf, "pause", 5)) {
                         pause ();
-                    } else {
+                    } else if (!strncmp (cmdbuf, "seek ", 5)) {
                         int d1, d2;
-                        if (!strncmp (cmdbuf, "seek ", 5)) {
-                            int nr = sscanf (cmdbuf + 5, "%d %d", &d1, &d2);
-                            if (nr > 1)
-                                seek (10 * d1, d2);
-                        } else if (!strncmp (cmdbuf, "volume ", 7)) {
-                            int nr = sscanf (cmdbuf + 7, "%d", &d1);
-                            if (nr > 0)
-                                volume (current_volume + d1);
+                        int nr = sscanf (cmdbuf + 5, "%d %d", &d1, &d2);
+                        if (nr > 1)
+                            seek (10 * d1, d2);
+                    } else if (!strncmp (cmdbuf, "volume ", 7)) {
+                        int d1;
+                        int nr = sscanf (cmdbuf + 7, "%d", &d1);
+                        if (nr > 0)
+                            volume (current_volume + d1);
+                    } else if (!strncmp (cmdbuf, "panzoom ", 8)) {
+                        int x, y, w, h;
+                        char sep;
+                        int nr = sscanf (cmdbuf + 8,
+                                "%d%c%d%c%d%c%d",
+                                &x, &sep, &y, &sep, &w, &sep, &h);
+                        if (nr == 7 &&
+                                x + w < movie_width &&
+                                y + h < movie_height,
+                                x >= 0 && y >= 0 && w > 0 && h > 0) {
+                            crop_x = x;
+                            crop_y = y;
+                            crop_width = w;
+                            crop_height = h;
+                            cb_video_dimension (NULL);
                         }
                     }
                 } else if (bufpos >= sizeof (cmdbuf)) {
