@@ -188,7 +188,7 @@ void app_normal_screen (Application *app) {
         gtk_window_unfullscreen (app->window);
         gtk_widget_show (app->playlist_area);
         gtk_widget_hide (app->video_stop);
-        gtk_widget_hide (app->aspects_toggle);
+        gtk_widget_hide (app->zoom_box);
         gtk_widget_hide (app->title_area);
         gtk_widget_hide (GTK_WIDGET (app->tb_favorites));
         gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 354);
@@ -218,7 +218,7 @@ void app_store_save_directory (Application *app, gchar *path) {
 static gboolean _controlsTimeout (Application *app)
 {
     gtk_widget_hide (app->video_stop);
-    gtk_widget_hide (app->aspects_toggle);
+    gtk_widget_hide (app->zoom_box);
     if (app->fullscreen)
         gtk_widget_hide (app->toolbar_area);
     gtk_widget_hide (app->title_area);
@@ -235,7 +235,7 @@ void app_show_controls (Application *app)
         gtk_widget_show_all (app->video_stop);
         if (app->show_playlist) {
             gtk_widget_show (app->toolbar_area);
-            gtk_widget_show_all (app->aspects_toggle);
+            gtk_widget_show_all (app->zoom_box);
         }
     }
 }
@@ -601,6 +601,7 @@ int main (int argc, char* argv[]) {
     GtkWidget *aspects_toggle;
     GtkWidget *info_box;
     GtkWidget *info_align;
+    GtkWidget *zoombox;
 
     setsid ();
 
@@ -649,16 +650,17 @@ int main (int argc, char* argv[]) {
     app->window_area = gtk_fixed_new ();
     app->view_area = gtk_fixed_new ();
     app->video_stop = gtk_event_box_new ();
-    app->aspects_toggle = gtk_event_box_new ();
+    app->zoom_box = gtk_event_box_new ();
     app->title_area = gtk_event_box_new ();
     app->playlist_area = hildon_pannable_area_new ();
     app->toolbar_area = gtk_event_box_new ();
     app->info_area = gtk_event_box_new ();
+    zoombox = gtk_vbox_new (false, 0);
     info_box = gtk_vbox_new (false, 0);
     info_align = gtk_alignment_new (0, 0, 1, 1);
 
     gtk_widget_set_size_request (app->video_stop, 70, 70);
-    gtk_widget_set_size_request (app->aspects_toggle, 70, 70);
+    gtk_widget_set_size_request (app->zoom_box, 70, 140);
     gtk_widget_set_size_request (app->title_area, 600, 70);
     gtk_widget_set_size_request (app->playlist_area, 800, 354);
     gtk_widget_set_size_request (app->toolbar_area, 800, 70);
@@ -680,11 +682,16 @@ int main (int argc, char* argv[]) {
     aspects_toggle = GTK_WIDGET(gtk_tool_button_new(gtk_image_new_from_icon_name(
                     "camera_video_resolution_wide_screen",
                     HILDON_ICON_SIZE_TOOLBAR), NULL));
+    app->panzoom_toggle = GTK_WIDGET(
+            gtk_tool_button_new(gtk_image_new_from_icon_name( "general_add",
+                    HILDON_ICON_SIZE_TOOLBAR), NULL));
 
     g_signal_connect (G_OBJECT (video_stop), "clicked",
             G_CALLBACK (cb_playlist_stop), app->control);
     g_signal_connect (G_OBJECT (aspects_toggle), "clicked",
             G_CALLBACK (cb_aspects_toggle), app->control);
+    g_signal_connect (G_OBJECT (app->panzoom_toggle), "clicked",
+            G_CALLBACK (cb_panzoom_toggle), app->control);
     gtk_widget_add_events (app->view_area,
             GDK_EXPOSURE_MASK | GDK_VISIBILITY_NOTIFY_MASK |
             GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK |
@@ -737,11 +744,13 @@ int main (int argc, char* argv[]) {
     g_object_ref (app->info_viewport);
     g_object_ref (app->html_viewport);
     gtk_container_add (GTK_CONTAINER (app->video_stop), video_stop);
-    gtk_container_add (GTK_CONTAINER (app->aspects_toggle), aspects_toggle);
+    gtk_container_add (GTK_CONTAINER (app->zoom_box), zoombox);
+    gtk_container_add (GTK_CONTAINER (zoombox), aspects_toggle);
+    gtk_container_add (GTK_CONTAINER (zoombox), app->panzoom_toggle);
 
     gtk_fixed_put (GTK_FIXED (app->window_area), app->view_area, 0, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->video_stop, 730, 0);
-    gtk_fixed_put (GTK_FIXED (app->window_area), app->aspects_toggle, 730, 205);
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->zoom_box, 730, 170);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->title_area, 100, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->playlist_area, 0, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->toolbar_area, 0, 354);
