@@ -80,7 +80,8 @@ typedef struct _Application {
     GtkWidget *video_prev;
     GtkWidget *video_up;
     GtkWidget *video_down;
-    GtkWidget *aspects_toggle;
+    GtkWidget *zoom_box;
+    GtkWidget *panzoom_toggle;
     GtkWidget * playlist_view;
     GtkWidget * downloads_view;
     GtkWidget * infopanel_view;
@@ -149,6 +150,7 @@ void cb_playlist_stop (GtkButton * button, void *ctr);
 void cb_playlist_save (GtkButton * button, void *ctr);
 void cb_favorites_add (GtkButton *, Application *app);
 void cb_aspects_toggle (GtkButton *, void *ctr);
+void cb_panzoom_toggle (GtkButton *, void *ctr);
 gboolean playlist_selected (Application *app, GValue *icon, GValue *text);
 void collapseSelectedList (Application *app);
 void expandSelectedList (Application *app);
