@@ -132,8 +132,10 @@ public:
     PlaylistItemBase (KMPlayer::NodePtr &d, short id, Application *a, bool pm);
     void activate ();
     void closed ();
+    void *role (KMPlayer::RoleType msg, void *content=NULL);
     Application * app;
     bool playmode;
+    bool hidden;
 };
 
 class KMPLAYER_NO_EXPORT PlaylistItem : public PlaylistItemBase {
@@ -163,14 +165,17 @@ public:
     const char * nodeName () const;
 };
 
-class KMPLAYER_NO_EXPORT PlaylistMetaGroup : public PlaylistGroupBase
+class KMPLAYER_NO_EXPORT PlaylistMetaGroup : public Mrl
 {
 public:
     PlaylistMetaGroup (KMPlayer::NodePtr &doc, Application *a);
     void closed ();
+    void activate ();
     KMPlayer::Node *childFromTag (const String &tag);
+    Node::PlayType playType () { return play_type_unknown; }
     KDE_NO_EXPORT const char *nodeName () const { return "meta"; }
     NodePtrW views;
+    Application *app;
 };
 
 class KMPLAYER_NO_EXPORT Views : public Element
@@ -192,6 +197,7 @@ public:
 
     void activate ();
     void closed ();
+    void *role (KMPlayer::RoleType msg, void *content=NULL);
     KDE_NO_EXPORT const char * nodeName () const { return "view"; }
     String groupBy;
     Expression *show;
