@@ -254,6 +254,7 @@ void Control::init () {
     gst->setAudioDriver ("pulse");
     gst->setVideoDriver ("xv");
     gst->setAutoSubTitles (true);
+    gst->setSupportsPanzoom (true);
     media_server = gst;
     if (glob ("/usr/bin/mplayer", 0, NULL, &globbuf) != GLOB_NOMATCH) {
         MPlayer *mp = new MPlayer (this, "mplayer");
@@ -1196,6 +1197,13 @@ void cb_aspects_toggle (GtkButton * button, void *p)
     ctr->updateViewAreaSizes ();
 }
 
+void cb_panzoom_toggle (GtkButton * button, void *p)
+{
+    Control *ctr = (Control *)p;
+    if (ctr->process ())
+        ctr->process ()->toggleScale ();
+}
+
 void cb_playlist_save (GtkButton * button, void *p) {
     Control *ctr = (Control *)p;
     if (ctr->current_selected) {
