@@ -96,6 +96,9 @@ KMPLAYER_NO_EXPORT bool Process::brightness (int /*pos*/, bool /*absolute*/) {
     return false;
 }
 
+void Process::toggleScale ()
+{}
+
 //bool Process::grabPicture (const KURL & /*url*/, int /*pos*/) {
 //    return false;
 //}
@@ -384,13 +387,15 @@ MPlayer::MPlayer (ProcessNotify *ctrl, const char *nm)
    audio_driver (NULL),
    video_driver (NULL),
    m_transition_state (NotRunning),
-   auto_sub_titles (false) {}
+   auto_sub_titles (false),
+   supports_panzoom (false),
+   needs_restarted (false) {}
 
 MPlayer::~MPlayer () {
 }
 
 KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
-    if (playing ()) {
+    if (!needs_restarted && playing ()) {
         if (node ||
                 (m_transition_state == Paused ||
                  (Paused == m_state && m_transition_state != Playing))) {
@@ -403,6 +408,8 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     }
     debugLog () << "MPlayer::play" << endl;
     m_transition_state = NotRunning;
+    if (!needs_restarted)
+        panzoom_enabled = false;
     setState (Buffering);
     Process::play (node);
     if (m_url.isEmpty ()) {
@@ -472,6 +479,7 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
 
     const TrieString aspect_ratio ("aspectRatio");
     bool found_attr = false;
+    String crop;
     for (Node *n = mrl; n && !found_attr; n = n->parentNode ()) {
         if (n->id != id_node_group_node && n->id != id_node_playlist_item)
             continue;
@@ -502,17 +510,32 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
             } else if (a->name () == Ids::attr_panzoom) {
                 String coord[4];
                 if (Mrl::parsePanZoomString (a->value (), coord)) {
-                    cmdline += String ("-vf crop=") +
+                    crop = String ("-vf crop=") +
                         String::number (coord[2].toInt()) + Char (':') +
                         String::number (coord[3].toInt()) + Char (':') +
                         String::number (coord[0].toInt()) + Char (':') +
                         String::number (coord[1].toInt());
                 }
-                cmdline += Char (' ');
                 found_attr = true;
             }
         }
     }
+    if (needs_restarted) {
+        int x, y, w, h;
+        needs_restarted = false;
+        if (panzoom_enabled && calculateScale (x, y, w, h)) {
+            crop = String ("-vf crop=") +
+                String::number (w) + Char (':') +
+                String::number (h) + Char (':') +
+                String::number (x) + Char (':') +
+                String::number (y);
+            m_width = w;
+            m_height = h;
+            updateAspects ();
+        }
+    }
+    if (!crop.isEmpty ())
+        cmdline += crop + Char (' ');
 
     char *quoted = g_shell_quote ((const char *) m_url);
     cmdline += String (quoted);
@@ -544,11 +567,13 @@ KMPLAYER_NO_EXPORT bool MPlayer::ready (unsigned int viewer) {
 
 KMPLAYER_NO_EXPORT bool MPlayer::stop () {
     debugLog() << "stop mplayer" << endl;
+    needs_restarted = false;
     return sendCommand (String ("quit"));
 }
 
 KMPLAYER_NO_EXPORT bool MPlayer::quit () {
     if (playing ()) {
+        needs_restarted = false;
         request_quit = true;
         stop ();
         while (g_main_context_iteration (0L, false))
@@ -607,11 +632,54 @@ KMPLAYER_NO_EXPORT bool MPlayer::brightness (int pos, bool absolute) {
     return true;
 }
 
+bool MPlayer::calculateScale (int &x, int &y, int &w, int &h)
+{
+    // TODO vertical scale
+    x = 0;
+    h = stream_width * 480 / 800;
+    if (h < 0)
+        return false;
+    y = (stream_height - h) / 2;
+    w = stream_width;
+    return true;
+}
+
+void MPlayer::toggleScale ()
+{
+    if (supports_panzoom && stream_width > 0 && stream_height > 0) {
+        char buf[64];
+        if (panzoom_enabled) {
+            panzoom_enabled = false;
+            snprintf (buf, sizeof (buf),
+                    "panzoom 0 0 %d %d", stream_width, stream_height);
+        } else {
+            int x, y, w, h;
+            if (!calculateScale (x, y, w, h))
+                return;
+            panzoom_enabled = true;
+            snprintf (buf, sizeof (buf), "panzoom %d %d %d %d", x, y, w, h);
+        }
+        sendCommand (String (buf));
+    } else {
+        panzoom_enabled = !panzoom_enabled;
+        needs_restarted = true;
+        sendCommand (String ("quit"));
+    }
+}
+
 KMPLAYER_NO_EXPORT void MPlayer::processExited (UnixProcess *) {
     unix_process.closeStdOut ();
     commands.clear ();
-    if (m_state > Ready && !request_quit)
+    debugLog() << "processExited restart " << needs_restarted << endl;
+    if (needs_restarted) {
+        int pos = m_position;
+        play (m_mrl);
+        seek (pos, true);
+        if (Paused == m_state)
+            pause ();
+    } else if (m_state > Ready && !request_quit) {
         setState (Ready);
+    }
 }
 
 KMPLAYER_NO_EXPORT void MPlayer::writeEvent (UnixProcess *) {
@@ -715,15 +783,21 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
                         } // else ignore, a second 'pause' cmd should follow
                     } else if (!strncmp (tok + 3, "VIDEO_WIDTH", 11)) {
                         m_width = (int) strtof (tok + 15, 0L);
+                        if (!panzoom_enabled)
+                            stream_width = m_width;
                         updateAspects ();
                     } else if (!strncmp (tok + 3, "VIDEO_HEIGHT", 12)) {
                         m_height = (int) strtof (tok + 16, 0L);
+                        if (!panzoom_enabled)
+                            stream_height = m_height;
                         updateAspects ();
                     } else if (!strncmp (tok + 3, "VIDEO_ASPECT", 12)) {
-                        // convert in C locale
-                        m_aspect = (float) String (tok + 16).toDouble ();
-                        if (m_aspect > 0.01)
-                            updateAspects ();
+                        if (!panzoom_enabled) {
+                            // convert in C locale
+                            m_aspect = (float) String (tok + 16).toDouble ();
+                            if (m_aspect > 0.01)
+                                updateAspects ();
+                        }
                     } else if (!strncmp (tok + 3, "REF", 3)) {
                         m_notify->insertMrl (mrl(), URL::decode_string(tok + 7));
                     }
