@@ -176,6 +176,36 @@ int main() {
         TEST_VERIFY (expr->toString () == "Uncle Tom's Cabin");
         delete expr;
     }
+    {
+        TEST_INFO (Test "escape-uri(//book[not(@price)]/title) == Uncle Tom's Cabin");
+        Expression *expr = evaluateExpr ("escape-uri(//book[not(@price)]/title)");
+        expr->setRoot (books);
+        TEST_VERIFY (expr->toString () == "Uncle%20Tom%27s%20Cabin");
+        delete expr;
+    }
+    {
+        TEST_INFO (Test "contains(//book[title=\"Uncle Tom's Cabin\"], 'Tom')");
+        Expression *expr = evaluateExpr ("contains(//book[title=\"Uncle Tom's Cabin\"], 'Tom')");
+        expr->setRoot (books);
+        TEST_VERIFY (expr->toBool ());
+        delete expr;
+    }
+    {
+        TEST_INFO (Test "//book/title[contains(.,'Tom')]");
+        Expression *expr = evaluateExpr ("//book/title[contains(.,'Tom')]");
+        expr->setRoot (books);
+        NodeValueList *lst = expr->toNodeList ();
+        TEST_VERIFY (lst->length () == 2);
+        NodeValueItem *itm = lst->first ();
+        if (itm) {
+            TEST_VERIFY (itm->data.value () == "Tom Sawyer");
+            itm = itm->nextSibling ();
+            if (itm)
+                TEST_VERIFY (itm->data.value () == "Uncle Tom's Cabin");
+        }
+        delete lst;
+        delete expr;
+    }
     books->document ()->dispose ();
     return 0;
 }
